<?php

/**
 * This library is a helper to easily retrieve design objects from EE (template groups, templates, snippets, global variables)
 */
class EE_templates_lib
{
	var $site_id;

	public function __construct($site_id)
	{
		$this->site_id = $site_id;
	}

	public function get_template_types()
	{
		return array('webpage','feed', 'css', 'js', 'static', 'xml');
	}

	/**
	 * Retrieve all template groups and their templates
	 * @return	collection				All template groups with their templates
	 */
	public function get_template_groups_with_templates()
	{

		// 'with()' is forcing to load all templates (instead of lazy-load)
		$templates = ee('Model')->get('TemplateGroup')->with('Templates')->filter('site_id', '==', $this->site_id)->all();
		
		return $templates;
	}
	
	/**
	 * Retrieve Template Groups without their templates
	 * @return [type]          [description]
	 */
	public function get_template_groups()
	{
		// Templates will be lazy-loaded (loaded when accessing them)
		$templates = ee('Model')->get('TemplateGroup')->filter('site_id', '==', $this->site_id)->all();
		
		return $templates;
	}
	
	/**
	 * Load a template group but not its templates
	 * @param  [type] $site_id  [description]
	 * @param  [type] $group_id [description]
	 * @return [type]           [description]
	 */
	public function get_template_group($group_id)
	{
		// Templates will be lazy-loaded (loaded when accessing them)
		$template_group = ee('Model')->get('TemplateGroup')->filter('site_id', '==', $this->site_id)->filter('group_id', '==', $group_id)->first();
		
		return $template_group;
	}
	
	/**
	 * The the site default template group
	 * @param  [type] $site_id [description]
	 * @return [type]          [description]
	 */
	public static function get_template_group_site_default($site_id)
	{
		$template_group = ee('Model')->get('TemplateGroup')->filter('site_id', '==', $site_id)->filter('is_site_default', '==', 'y')->first();
		
		return $template_group;
	}
	
	/**
	 * Get templates from a specific template group
	 * @param  [type] $site_id  [description]
	 * @param  [type] $group_id [description]
	 * @return Collection       Collection of Templates
	 */
	public static function get_templates($site_id, $group_id)
	{
		$templates = ee('Model')->get('Template')->filter('site_id', '==', $site_id)->filter('group_id', '==', $group_id)->all();
		
		return $templates;
	}
	
	/**
	 * Get a unique template from its Id
	 * @param  [type] $template_id [description]
	 * @return [type]              [description]
	 */
	public function get_template($template_id)
	{
		$template = ee('Model')->get('Template')->with('Versions')->filter('site_id', '==', $this->site_id)->filter('template_id', '==', $template_id)->first();
		
		return $template;
	}

	public function get_template_from_name($template_group_id, $template_name)
	{
		$template = ee('Model')->get('Template')->with('Versions')->filter('site_id', '==', $this->site_id)->filter('group_id', '==', $template_group_id)->filter('template_name', '==', $template_name)->first();

		return $template;
	}

	/**
	 * Test if a template with that name exists in that template group
	 */
	public function template_with_name_exists($template_group_id, $template_name)
	{
		$template = $this->get_template_from_name($template_group_id, $template_name);

		return ($template != NULL);
	}
	
	/**
	 * Retrieve all snippets
	 * @return collection   All snippets for the current site
	 */
	public function get_snippets()
	{
		$snippets = ee('Model')->get('Snippet')->filter('site_id', '==', $this->site_id)->all();
		
		return $snippets;
	}

	/**
	 * Retrieve snippets for all MSM websites (global snippets)
	 * @return collection   Snippets for all MSM sites
	 */
	public function get_global_snippets()
	{
		$snippets = ee('Model')->get('Snippet')->filter('site_id', '==', 0)->all();
		
		return $snippets;
	}
	
	/**
	 * Retrieve one snippet
	 */
	public function get_snippet($snippet_id)
	{
		$snippet = ee('Model')->get('Snippet')->filter('snippet_id', '==', $snippet_id)->filter('site_id', '==', $this->site_id)->orFilter('site_id', '==', 0)->first();
		
		return $snippet;
	}

	/**
	 * Retrieve a snippet from its name 
	 */
	public function get_snippet_from_name($snippet_name)
	{
		$snippet = ee('Model')->get('Snippet')->filter('snippet_name', '==', $snippet_name)->first();

		return $snippet;
	}

	/**
	 * Test if a snippet with that name exists
	 */
	public function snippet_with_name_exists($snippet_name)
	{
		$snippet = $this->get_snippet_from_name($snippet_name);

		return ($snippet != NULL);
	}
	
	/**
	 * Retrieve all global variables
	 * @return collection          	All variables
	 */
	public function get_global_variables()
	{
		$variables = ee('Model')->get('GlobalVariable')->filter('site_id', '==', $this->site_id)->all();
		
		return $variables;
	}
	
	public function get_global_variable($variable_id)
	{
		$variable = ee('Model')->get('GlobalVariable')->filter('site_id', '==', $this->site_id)->filter('variable_id', '==', $variable_id)->first();
		
		return $variable;
	}

	public function get_global_variable_from_name($variable_name)
	{
		$variable = ee('Model')->get('GlobalVariable')->filter('site_id', '==', $this->site_id)->filter('variable_name', '==', $variable_name)->first();
		
		return $variable;
	}

	/**
	 * Test if a global variable with that name exists
	 */
	public function global_variable_with_name_exists($variable_name)
	{
		$variable = $this->get_global_variable_from_name($variable_name);

		return ($variable != NULL);
	}
}